@@ -17,7 +17,7 @@
 import datetime
 
 import mock
-from oslo.utils import strutils
+from oslo_utils import strutils
 import six
 from six.moves.urllib import parse
 
